"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var TNSCall = (function () {
    function TNSCall() {
    }
    TNSCall.prototype.receiveCall = function (options) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            TNSCall.handle = CXHandle.alloc().initWithTypeValue(!options || options.handleType === "PHONE" ? 2 : 3, options.handleId);
            var callUUID = NSUUID.new();
            var callUpdate = CXCallUpdate.new();
            callUpdate.remoteHandle = TNSCall.handle;
            if (options.callerName) {
                callUpdate.localizedCallerName = options.callerName;
            }
            callUpdate.hasVideo = options && options.hasVideo;
            callUpdate.supportsDTMF = options && options.supportsDTMF;
            callUpdate.supportsGrouping = false;
            callUpdate.supportsUngrouping = false;
            callUpdate.supportsHolding = false;
            _this.ensureProvider();
            TNSCall.provider.reportNewIncomingCallWithUUIDUpdateCompletion(callUUID, callUpdate, function (error) {
                if (error === null) {
                    resolve();
                }
                else {
                    console.log("Incoming call error: " + error.localizedDescription);
                    reject(error.localizedDescription);
                }
            });
        });
    };
    TNSCall.prototype.endCall = function () {
        return new Promise(function (resolve, reject) {
            var calls = TNSCall.callController.callObserver.calls;
            if (calls.count === 1) {
                var endCallAction = CXEndCallAction.alloc().initWithCallUUID(calls[0].UUID);
                var transaction = CXTransaction.alloc().initWithAction(endCallAction);
                TNSCall.callController.requestTransactionCompletion(transaction, function (error) {
                    if (error === null) {
                        resolve();
                    }
                    else {
                        console.log("Error ending call: " + error.localizedDescription);
                        reject(error.localizedDescription);
                    }
                });
            }
            else {
                reject("No calls active");
            }
        });
    };
    TNSCall.prototype.ensureProvider = function () {
        if (TNSCall.provider) {
            return;
        }
        var appName = NSBundle.mainBundle.objectForInfoDictionaryKey("CFBundleDisplayName");
        var providerConfiguration = CXProviderConfiguration.alloc().initWithLocalizedName(appName);
        providerConfiguration.maximumCallGroups = 1;
        providerConfiguration.maximumCallsPerCallGroup = 1;
        var handleTypes = NSMutableSet.new();
        handleTypes.addObject(3);
        handleTypes.addObject(2);
        providerConfiguration.supportedHandleTypes = handleTypes;
        providerConfiguration.supportsVideo = true;
        TNSCall.provider = CXProvider.alloc().initWithConfiguration(providerConfiguration);
        TNSCall.provider.setDelegateQueue(CXProviderDelegateImpl.initWithOwner(new WeakRef(this)), null);
        TNSCall.callController = CXCallController.new();
    };
    return TNSCall;
}());
exports.TNSCall = TNSCall;
var CXProviderDelegateImpl = (function (_super) {
    __extends(CXProviderDelegateImpl, _super);
    function CXProviderDelegateImpl() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CXProviderDelegateImpl.initWithOwner = function (owner) {
        var delegate = _super.new.call(this);
        delegate.owner = owner;
        return delegate;
    };
    CXProviderDelegateImpl.prototype.providerDidReset = function (provider) {
        console.log("delegate, providerDidReset");
    };
    CXProviderDelegateImpl.prototype.providerDidActivateAudioSession = function (provider, audioSession) {
        console.log("delegate, providerDidActivateAudioSession");
    };
    CXProviderDelegateImpl.prototype.providerDidBegin = function (provider) {
        console.log("delegate, providerDidBegin");
    };
    CXProviderDelegateImpl.prototype.providerDidDeactivateAudioSession = function (provider, audioSession) {
        console.log("delegate, providerDidDeactivateAudioSession");
    };
    CXProviderDelegateImpl.prototype.providerExecuteTransaction = function (provider, transaction) {
        console.log("delegate, providerExecuteTransaction");
        return true;
    };
    CXProviderDelegateImpl.prototype.providerPerformAnswerCallAction = function (provider, action) {
        console.log("delegate, providerPerformAnswerCallAction");
    };
    CXProviderDelegateImpl.prototype.providerPerformEndCallAction = function (provider, action) {
        var calls = TNSCall.callController.callObserver.calls;
        if (calls.count === 1) {
            if (calls[0].hasConnected) {
                console.log("Ended connected call (hang up)");
            }
            else {
                console.log("Ended non-connected call (rejected)");
            }
        }
    };
    CXProviderDelegateImpl.prototype.providerPerformPlayDTMFCallAction = function (provider, action) {
        console.log("delegate, providerPerformPlayDTMFCallAction");
    };
    CXProviderDelegateImpl.prototype.providerPerformSetGroupCallAction = function (provider, action) {
        console.log("delegate, providerPerformSetGroupCallAction");
    };
    CXProviderDelegateImpl.prototype.providerPerformSetHeldCallAction = function (provider, action) {
        console.log("delegate, providerPerformSetHeldCallAction");
    };
    CXProviderDelegateImpl.prototype.providerPerformSetMutedCallAction = function (provider, action) {
        console.log("delegate, providerPerformSetMutedCallAction");
    };
    CXProviderDelegateImpl.prototype.providerPerformStartCallAction = function (provider, action) {
        console.log("delegate, providerPerformStartCallAction");
    };
    CXProviderDelegateImpl.prototype.providerTimedOutPerformingAction = function (provider, action) {
        console.log("delegate, providerTimedOutPerformingAction");
    };
    CXProviderDelegateImpl = __decorate([
        ObjCClass(CXProviderDelegate)
    ], CXProviderDelegateImpl);
    return CXProviderDelegateImpl;
}(NSObject));
//# sourceMappingURL=call.ios.js.map